==> openshift-model-monitoring-4.11.1-sources.jar: io/fabric8/openshift/api/model/monitoring/v1/AlertmanagerListFluent.java <==
package io.fabric8.openshift.api.model.monitoring.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import io.fabric8.kubernetes.api.builder.Predicate;
import io.fabric8.kubernetes.api.model.ListMeta;
import java.lang.StringBuffer;
import java.lang.Deprecated;
import java.lang.Long;
import java.util.Iterator;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

public interface AlertmanagerListFluent<A extends AlertmanagerListFluent<A>> extends Fluent<A>{


    public String getApiVersion();
    public A withApiVersion(String apiVersion);
    public Boolean hasApiVersion();
    public A withNewApiVersion(String arg1);
    public A withNewApiVersion(StringBuilder arg1);
    public A withNewApiVersion(StringBuffer arg1);
    public A addToItems(int index,Alertmanager item);
    public A setToItems(int index,Alertmanager item);
    public A addToItems(Alertmanager... items);
    public A addAllToItems(Collection<Alertmanager> items);
    public A removeFromItems(Alertmanager... items);
    public A removeAllFromItems(Collection<Alertmanager> items);
    public A removeMatchingFromItems(io.fabric8.kubernetes.api.builder.Predicate<AlertmanagerBuilder> predicate);
    
/**
 * This method has been deprecated, please use method buildItems instead.
 * @return The buildable object.
 */
@Deprecated public List<Alertmanager> getItems();
    public List<Alertmanager> buildItems();
    public Alertmanager buildItem(int index);
    public Alertmanager buildFirstItem();
    public Alertmanager buildLastItem();
    public Alertmanager buildMatchingItem(io.fabric8.kubernetes.api.builder.Predicate<AlertmanagerBuilder> predicate);
    public Boolean hasMatchingItem(io.fabric8.kubernetes.api.builder.Predicate<AlertmanagerBuilder> predicate);
    public A withItems(List<Alertmanager> items);
    public A withItems(Alertmanager... items);
    public Boolean hasItems();
    public AlertmanagerListFluent.ItemsNested<A> addNewItem();
    public AlertmanagerListFluent.ItemsNested<A> addNewItemLike(Alertmanager item);
    public AlertmanagerListFluent.ItemsNested<A> setNewItemLike(int index,Alertmanager item);
    public AlertmanagerListFluent.ItemsNested<A> editItem(int index);
    public AlertmanagerListFluent.ItemsNested<A> editFirstItem();
    public AlertmanagerListFluent.ItemsNested<A> editLastItem();
    public AlertmanagerListFluent.ItemsNested<A> editMatchingItem(io.fabric8.kubernetes.api.builder.Predicate<AlertmanagerBuilder> predicate);
    public String getKind();
    public A withKind(String kind);
    public Boolean hasKind();
    public A withNewKind(String arg1);
    public A withNewKind(StringBuilder arg1);
    public A withNewKind(StringBuffer arg1);
    public ListMeta getMetadata();
    public A withMetadata(ListMeta metadata);
    public Boolean hasMetadata();
    public A withNewMetadata(String _continue,Long remainingItemCount,String resourceVersion,String selfLink);

    public interface ItemsNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,AlertmanagerFluent<AlertmanagerListFluent.ItemsNested<N>>{

        
    public N and();    public N endItem();
}


}

==> openshift-model-monitoring-5.1.1-sources.jar: io/fabric8/openshift/api/model/monitoring/v1/AlertmanagerListFluent.java <==
package io.fabric8.openshift.api.model.monitoring.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import io.fabric8.kubernetes.api.model.ListMeta;
import java.util.function.Predicate;
import java.lang.StringBuffer;
import java.lang.Deprecated;
import java.lang.Long;
import java.util.Iterator;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

public interface AlertmanagerListFluent<A extends AlertmanagerListFluent<A>> extends Fluent<A> {


    public String getApiVersion();
    public A withApiVersion(String apiVersion);
    public Boolean hasApiVersion();
    public A withNewApiVersion(String arg1);
    public A withNewApiVersion(StringBuilder arg1);
    public A withNewApiVersion(StringBuffer arg1);
    public A addToItems(int index,Alertmanager item);
    public A setToItems(int index,Alertmanager item);
    public A addToItems(Alertmanager... items);
    public A addAllToItems(Collection<Alertmanager> items);
    public A removeFromItems(Alertmanager... items);
    public A removeAllFromItems(Collection<Alertmanager> items);
    public A removeMatchingFromItems(Predicate<AlertmanagerBuilder> predicate);
    
/**
 * This method has been deprecated, please use method buildItems instead.
 * @return The buildable object.
 */
@Deprecated public List<Alertmanager> getItems();
    public List<Alertmanager> buildItems();
    public Alertmanager buildItem(int index);
    public Alertmanager buildFirstItem();
    public Alertmanager buildLastItem();
    public Alertmanager buildMatchingItem(Predicate<AlertmanagerBuilder> predicate);
    public Boolean hasMatchingItem(Predicate<AlertmanagerBuilder> predicate);
    public A withItems(List<Alertmanager> items);
    public A withItems(Alertmanager... items);
    public Boolean hasItems();
    public AlertmanagerListFluent.ItemsNested<A> addNewItem();
    public AlertmanagerListFluent.ItemsNested<A> addNewItemLike(Alertmanager item);
    public AlertmanagerListFluent.ItemsNested<A> setNewItemLike(int index,Alertmanager item);
    public AlertmanagerListFluent.ItemsNested<A> editItem(int index);
    public AlertmanagerListFluent.ItemsNested<A> editFirstItem();
    public AlertmanagerListFluent.ItemsNested<A> editLastItem();
    public AlertmanagerListFluent.ItemsNested<A> editMatchingItem(Predicate<AlertmanagerBuilder> predicate);
    public String getKind();
    public A withKind(String kind);
    public Boolean hasKind();
    public A withNewKind(String arg1);
    public A withNewKind(StringBuilder arg1);
    public A withNewKind(StringBuffer arg1);
    public ListMeta getMetadata();
    public A withMetadata(ListMeta metadata);
    public Boolean hasMetadata();
    public A withNewMetadata(String _continue,Long remainingItemCount,String resourceVersion,String selfLink);
    public interface ItemsNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,AlertmanagerFluent<AlertmanagerListFluent.ItemsNested<N>> {

            public N and();
            public N endItem();    }


}
